#pragma once
#include <imgui.h>

class MainMenuBar {

public:
	MainMenuBar() { ImGui::BeginMainMenuBar(); }

	void ApplicationMenu(std::unique_ptr<Project>& project) {

        if (ImGui::BeginMenu("Application")) {

            if (ImGui::MenuItem("Load Project"))
            {
                nfdresult_t result = NFD_OpenDialog({ "yproj" }, NULL, &path);
                switch (result) {
                case(NFD_OKAY):
                    Project::LoadProject(path, project);
                    AssetManager::setAssetPath(project.get()->GetProjectDirectory());
                    AssetManager::BuildAssetView();
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    std::cout << "NFD_Error: " << NFD_GetError() << std::endl;
                    break;
                }

            }

            if (ImGui::MenuItem("Save project as...")) {
                nfdresult_t result = NFD_SaveDialog({ "yproj" }, NULL, &path);
                switch (result) {
                case(NFD_OKAY):
                    std::cout << "Save as: " << path << std::endl;
                    Project::SaveProject(path, *project.get());
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    std::cout << "NFD_Error: " << NFD_GetError() << std::endl;
                    break;
                }
            }



            if (ImGui::MenuItem("Preferences"))
            {

            }

            if (ImGui::MenuItem("Exit"))
            {
                // TODO: Exit application
            }

            ImGui::EndMenu();
        }
	}

    void SceneMenu(std::unique_ptr<Project>& project,  Scene& scene) {

        if (ImGui::BeginMenu("Scene")) {

            if (ImGui::MenuItem("Save scene"))
            {
                nfdresult_t result = NFD_SaveDialog({ "yscene" }, NULL, &path);
                switch (result) {
                case(NFD_OKAY):
                    SaveScene(path, scene);
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    std::cout << "NFD_Error: " << NFD_GetError() << std::endl;
                    break;
                }

            }

            if (ImGui::MenuItem("Load scene"))
            {
                auto result = NFD_OpenDialog({ "yscene" }, NULL, &path);
                switch (result) {
                case (NFD_OKAY):
                    LoadScene(path, scene);
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    std::cout << "NFD_Error: " << NFD_GetError() << std::endl;
                    break;
                }

            }

            if (ImGui::MenuItem("Add Entity"))
            {
                scene.AddEntity("New Entity");
            }

            if (ImGui::MenuItem("Import Model"))
            {
                auto result = NFD_OpenDialog("obj,fbx,gltf", NULL, &path);
                switch (result) {
                case(NFD_OKAY):
                    // Import Model
                    AssetManager::LoadFromSource(
                        path,
                        project.get()->GetProjectDirectory() / "Assets"
                    );
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    std::cout << "NFD_Error: " << NFD_GetError() << std::endl;
                    break;
                }
            }

            if (ImGui::MenuItem("Import MeshAsset (temp)"))
            {
                auto result = NFD_OpenDialog("mesh", NULL, &path);
                switch (result) {
                case(NFD_OKAY):
                    AssetManager::LoadFromAssetFile(path);
                    break;
                case(NFD_CANCEL):
                    break;
                case(NFD_ERROR):
                    break;
                }

            }

            ImGui::EndMenu();
        }
    }

	~MainMenuBar() { ImGui::EndMainMenuBar(); }
private:
    char* path = nullptr;

};