#include <YoggieEngine.h>
#include "Application.h"
#include <PxPhysicsAPI.h>
#define PVD_HOST "127.0.0.1"

using namespace physx;

namespace YoggieEngine {

	static PxDefaultErrorCallback gDefaultErrorCallback;
	static PxDefaultAllocator gDefaultAllocatorCallback;
	static PxFoundation* mFoundation;
	static PxPvd* mPvd;
	static PxPvdTransport* transport;
	static PxPhysics* mPhysics;
	bool recordMemoryAllocations = true;
	

	Application::Application(const std::string& name )
		: m_AppName(name)
	{
		EngineInstrumentation::PerfomanceSamplerInit();

		// startup PhysX
		mFoundation = PxCreateFoundation(PX_PHYSICS_VERSION, gDefaultAllocatorCallback, gDefaultErrorCallback);
		if (!mFoundation) {
			spdlog::critical("PxCreateFoundation failed!");
		}

		mPvd = physx::PxCreatePvd(*mFoundation);
		if (!mPvd) {
			spdlog::critical("pxCreatPvd failed!");
		}
		transport = PxDefaultPvdSocketTransportCreate(PVD_HOST, 5425, 10);
		mPvd->connect(*transport, PxPvdInstrumentationFlag::eALL);


		mPhysics = PxCreatePhysics(PX_PHYSICS_VERSION, *mFoundation, PxTolerancesScale(), recordMemoryAllocations, mPvd);
		if (!mPhysics) {
			spdlog::critical("pxCreatePhysics failed!");
		}
		
	}


	void Application::Run() {
		std::cout << "No run function implemented!";
	}


	Application::~Application(){

	if (mPhysics)
		mPhysics->release();

	if (mPvd) {
		if (mPvd->isConnected()) {
			mPvd->disconnect();
		}
		mPvd->release();
	}

	if (transport)
		transport->release();
	

	if (mFoundation)
		mFoundation->release();
	}

}